@@ -56,7 +56,8 @@ impl PhpProvider {
             _ => "php".to_string(),
         };
 
-        let php_extensions = PhpProvider::get_php_extensions(app).unwrap_or(vec![]);
+        let mut php_extensions = PhpProvider::get_php_extensions(app).unwrap_or(vec![]);
+        php_extensions.sort_unstable();
 
         let mut pkgs = vec![
             Pkg::new(&format!(
